import { TypedFormData } from "./typedFormData";
/**
 * The page payload consists of multiple data parts. The first data part is the 'Presentation'
 * that describes the elements that render on the page itself as ONML. Subsequent data parts are referenced
 * by the Presentation, e.g. binary data.
 */
export declare class OneNotePage {
    private dataParts;
    private title;
    private presentationBody;
    private locale;
    private pageMetadata;
    constructor(title?: string, presentationBody?: string, locale?: string, pageMetadata?: {
        [key: string]: string;
    });
    /**
     * Includes everything inside and including the <html> tags
     */
    getEntireOnml(): string;
    private getHeadAsHtml;
    private getPageMetadataAsHtml;
    private formUtcOffsetString;
    private generateMimePartName;
    escapeHtmlEntities(value: string): string;
    /**
     * Converts the Presentation and subsequent data parts entirely into data parts
     */
    getTypedFormData(): TypedFormData;
    addOnml(onml: string): void;
    addHtml(html: string): string;
    addImage(imgUrl: string): void;
    /**
     * The input can either be a url, or a reference to a MIME part containing binary
     * e.g., "name:REFERENCE"
     */
    addObjectUrlAsImage(url: string): void;
    addAttachment(binary: ArrayBuffer, name: string): string;
    addUrl(url: string): void;
    addCitation(format: string, urlToDisplay: string, rawUrl?: string): void;
}
